@@ -87,10 +87,14 @@ class BasePublisher(object):
         if handler is None:
             raise http.Http404
         # Do we need to pass any of this?
+        return self.execute(handler, request, action=action, object_id=object_id,
+            **kwargs
+        )
+
+    def execute(self, handler, *args, **kwargs):
+        '''This allows wrapping calls to handler functions'''
         try:
-            return handler(request, action=action, object_id=object_id,
-                **kwargs
-            )
+            return handler(request, *args, **kwargs)
         except http.BaseHttpResponse as response:
             return response
 
@@ -176,7 +180,7 @@ class Publisher(engine.JsonEngine, BasePublisher):
             else:
                 page_num = offset // page_size
 
-        paginator = Paginator(object_list, page_size)
+        paginator = Paginator(object_list, page_size, allow_empty_first_page=True)
         page = paginator.page(page_num + 1)
         return {
             'meta': {
